@@ -13,7 +13,6 @@
 -- You should have received a copy of the GNU General Public License    
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require "instrumentation"
 require "network"
 require "pages"
 require "resources"
@@ -23,7 +22,12 @@ require "derived"
 math.randomseed (os.time())
 
 graphics.close = function ()
-		    common.iterate = false
+		    if options.interactive then
+		       network.block = true
+		       graphics.hide = true
+		    else
+		       common.iterate = false
+		    end
 		 end
 
 -- Right now full shading only works on 'certain' GPUs.
@@ -41,6 +45,7 @@ if not common.engineering and not options.notoon and
 end
 
 -- These values are fixed.
+
 graphics.title = "Billiards"
 dynamics.collision = {}
 derived.frustum = {45, 0.001, 20}
@@ -54,12 +59,20 @@ network.archive = network.bookmark {
    path = os.getenv ("HOME") .. "/.billiards.d"
 }
 
+network.archive.tags = resources.loadcache (os.getenv ("HOME") .. "/.billiards.d/tags.lua")
+
 -- Load the default configuration.
 
 resources.dofile "billiards/common.lua"
 resources.dofile "billiards/defaults.lua"
 resources.dofile "billiards/resources.lua"
 
+if not options.interactive and not (options.eightball or
+				    options.nineball or
+				    options.carom) then
+   options.eightball = true
+end
+
 if options.eightball or
    options.nineball then
    options.pool = true
