@@ -19,10 +19,14 @@ require "transitions"
 -- Set up the controls.
 
 graph.controls = frames.event {
-		  
    keypress = function (self, key)
-      if key == 'q' then
-	 common.iterate = false
+      if key == 'escape' then
+	 if options.interactive then
+	    network.block = true
+	    graphics.hide = true
+	 else
+	    common.iterate = false
+	 end
       elseif key == 'p' then
 	 if dynamics.oldtimescale then
 	    dynamics.timescale = dynamics.oldtimescale
