@@ -36,6 +36,17 @@
   <a href = "/">back</a>
   <hr> 
 
+  <?lua
+      if billiards.started then
+	 return [[
+    <form class="pseudoform" name="resumegame" action="/" method="post">
+      <input type="hidden" name="resumegame" value="true" />
+        <p>There's a game currently in progress.  If you've stopped it you can resume it <a href="javascript:document.resumegame.submit();">by clicking here</a>.</p>
+    </form>
+	    ]]
+      end
+   ?>
+
   <p>You can use the following links to start a new game.  Note that
     this only selects the proper table type and sets up the balls
     according to the specified game's opening positions. No rule checking
@@ -50,61 +61,51 @@
     <li> Pocket games
       <ul>
 	<li>
-	  <a href="/newgame?newgame=true&options.eightball=true&options.pool=true">
-	    Eight-ball
-	  </a>
+	  <form class="pseudoform" name="eightballgame" action="/" method="post">
+	    <input type="hidden" name="newgame" value="true" />
+	    <input type="hidden" name="options.eightball" value="true" />
+	    <input type="hidden" name="options.pool" value="true" />
+	    <input type="hidden" name="options.billiards" value="false" />
+	    <a href="javascript:document.eightballgame.submit();">
+	      Eight-ball
+	    </a>
+	  </form>
+	</li>
 	<li>
-	  <a href="/newgame?newgame=true&options.nineball=true&options.pool=true">
-	    Nine-ball
-	  </a>
+	  <form class="pseudoform" name="nineballgame" action="/" method="post">
+	    <input type="hidden" name="newgame" value="true" />
+	    <input type="hidden" name="options.nineball" value="true" />
+	    <input type="hidden" name="options.pool" value="true" />
+	    <input type="hidden" name="options.billiards" value="false" />
+	    <a href="javascript:document.nineballgame.submit();">
+	      Nine-ball
+	    </a>
+	  </form>
+	</li>
       </ul>
     <li> Pocketless games
       <ul>
 	<li>
-	  <a href="/newgame?newgame=true&options.carom=true&options.billiards=true">
-	    Billiards
-	  </a>
+	  <form class="pseudoform" name="caromgame" action="/" method="post">
+	    <input type="hidden" name="newgame" value="true" />
+	    <input type="hidden" name="options.carom" value="true" />
+	    <input type="hidden" name="options.pool" value="false" />
+	    <input type="hidden" name="options.billiards" value="true" />
+	    <a href="javascript:document.caromgame.submit();">
+	      Billiards
+	    </a>
+	  </form>
+	</li>
       </ul>
   </ul>
 
   <p>
-    <form action="/newgame" enctype="multipart/form-data" method="post">
+    <form name="importgame" action="/" enctype="multipart/form-data" method="post">
       <input type="hidden" name="importgame" value="true" />
-      You can also select a game that has been exported to a file: <input type="file" name="file" /> and <a href="javascript:document.forms[0].submit();">import</a> it.
+      You can also select a game that has been exported to a file: <input type="file" name="file" /> and <a href="javascript:document.importgame.submit();">import</a> it.
     </form>
   </p>
 
-  <?lua
-    if query.newgame then
-       billiards.history = {}
-
-       billiards.opening = nil
-       billiards.decals = nil
-
-       options.eightball = false
-       options.nineball = false
-       options.carom = false
-
-       options.pool = false
-       options.billiards = false
-
-       for key, value in pairs (query) do
-	  assert (loadstring(key .. "=" .. value))()
-       end
-
-       resources.dofile "billiards/restart.lua"
-    end
-
-    if query.importgame and #query.file[3] > 0 then
-       restoregame = loadstring(query.file[3])
-
-       if restoregame then
-	  restoregame()
-	  resources.dofile "billiards/restart.lua"
-       end
-    end
-  ?>
-
   </table>
   <hr> 
   
