@@ -22,7 +22,8 @@ require "dynamics"
 
 local function scale(mesh)
    local n = mesh.size[1]
-   local k = #mesh.vertices / mesh.size[1]
+   -- TODO: Fix this with Lua 5.2 arrives.
+   local k = mesh.vertices[8 * n] and 8 or 3-- #mesh.vertices / mesh.size[1]
    local dx = 0.5 * (billiards.tablewidth - 2.84)
    local dy = 0.5 * (billiards.tableheight - 1.42)
 
